Stan Math Library: stan/math/prim/arr/meta/value_type.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
value_type.hpp File Reference
`#include <stan/math/prim/scal/meta/value_type.hpp>`
`#include <vector>`

Go to the source code of this file.

## Classes
struct | stan::math::value_type< std::vector< T > >
| Template metaprogram class to compute the type of values stored in a standard vector. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.